=======
Credits
=======

Development Lead
----------------

* Guilherme Castelao <guilherme@castelao.net>

Contributors
------------

* Luiz Irber <luiz.irber@gmail.com>; Plenty suggestions, discussions and contributions.
* David Goldsmith <eulergaussriemann@gmail.com>; Edited overview.rst.
* Rohan Dandavati; Provided the CTD-bottle example file: MI18MHDR.btl
* Suki Wong; Reported bug #42 on cnv2nc.
* Paul Focke; Position base splitting #45.
* Amber York; Reporting bug $41 on reading bottle files.
* Achim Randelhoff; minor improvements in documentation
* Uday Bhaskar; Provided SK287_CTD05.cnv, data columns with headers.
                Reported bad path on seabird_dir() for windows machines.
